summaryrefslogtreecommitdiffstats
path: root/kdirstat/kdirstatsettings.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:04 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:04 -0600
commita327682a10bf292b58ea4f2b5d47509f3150a5c6 (patch)
tree0d195090492524b7a80f499453d2d29f024a1ff6 /kdirstat/kdirstatsettings.cpp
parentc71ade2e373d85acf1357494b42202293dd771d2 (diff)
downloadkdirstat-a327682a10bf292b58ea4f2b5d47509f3150a5c6.tar.gz
kdirstat-a327682a10bf292b58ea4f2b5d47509f3150a5c6.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit c71ade2e373d85acf1357494b42202293dd771d2.
Diffstat (limited to 'kdirstat/kdirstatsettings.cpp')
-rw-r--r--kdirstat/kdirstatsettings.cpp78
1 files changed, 39 insertions, 39 deletions
diff --git a/kdirstat/kdirstatsettings.cpp b/kdirstat/kdirstatsettings.cpp
index b3d036f..e33a515 100644
--- a/kdirstat/kdirstatsettings.cpp
+++ b/kdirstat/kdirstatsettings.cpp
@@ -12,7 +12,7 @@
#include <tqcheckbox.h>
#include <tqcombobox.h>
#include <tqlabel.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlineedit.h>
#include <tqslider.h>
#include <tqvbox.h>
@@ -44,21 +44,21 @@ KSettingsDialog::KSettingsDialog( KDirStatApp *mainWin )
{
/**
* This may seem like overkill, but I didn't find any other way to get
- * geometry management right with KDialogBase, yet maintain a modular and
+ * tqgeometry management right with KDialogBase, yet maintain a modular and
* object-oriented design:
*
* Each individual settings page is added with 'addVBoxPage()' to get some
- * initial geometry management. Only then can some generic widget be added
+ * initial tqgeometry management. Only then can some generic widget be added
* into this - and I WANT my settings pages to be generic widgets. I want
* them to be self-sufficient - no monolithic mess of widget creation in my
* code, intermixed with all kinds of layout objects.
*
* The ordinary KDialogBase::addPage() just creates a TQFrame which is too
- * dumb for any kind of geometry management - it cannot even handle one
+ * dumb for any kind of tqgeometry management - it cannot even handle one
* single child right. So, let's have KDialogBase create something more
* intelligent: A TQVBox (which is derived from TQFrame anyway). This TQVBox
* gets only one child - the KSettingsPage. This KSettingsPage handles its
- * own layout.
+ * own tqlayout.
**/
TQWidget * page;
@@ -79,7 +79,7 @@ KSettingsDialog::KSettingsDialog( KDirStatApp *mainWin )
_generalSettingsPageIndex = pageIndex( page );
new KGeneralSettingsPage( this, page, _mainWin );
- // resize( sizeHint() );
+ // resize( tqsizeHint() );
}
@@ -166,14 +166,14 @@ KTreeColorsPage::KTreeColorsPage( KSettingsDialog * dialog,
, _treeView( mainWin->treeView() )
, _maxButtons( KDirStatSettingsMaxColorButton )
{
// Outer layout box
TQHBoxLayout * outerBox = new TQHBoxLayout( this,
0, // border
dialog->spacingHint() );
// Inner layout box with a column of color buttons
TQGridLayout *grid = new TQGridLayout( _maxButtons, // rows
_maxButtons + 1, // cols
@@ -190,7 +190,7 @@ KTreeColorsPage::KTreeColorsPage( KSettingsDialog * dialog,
{
TQString labelText;
- labelText=i18n( "Tree Level %1" ).arg(i+1);
+ labelText=i18n( "Tree Level %1" ).tqarg(i+1);
_colorLabel[i] = new TQLabel( labelText, this );
grid->addWidget( _colorLabel [i], i, 0 );
@@ -284,9 +284,9 @@ KCleanupPage::KCleanupPage( KSettingsDialog * dialog,
_workCleanupCollection = *mainWin->cleanupCollection();
- // Create layout and widgets.
+ // Create tqlayout and widgets.
- TQHBoxLayout * layout = new TQHBoxLayout( this,
+ TQHBoxLayout * tqlayout = new TQHBoxLayout( this,
0, // border
dialog->spacingHint() ); // spacing
_listBox = new KCleanupListBox( this );
@@ -302,17 +302,17 @@ KCleanupPage::KCleanupPage( KSettingsDialog * dialog,
this, TQT_SLOT ( changeCleanup( KCleanup * ) ) );
- // Fill list box so it can determine a reasonable startup geometry - that
+ // Fill list box so it can determine a reasonable startup tqgeometry - that
// doesn't work if it happens only later.
setup();
// Now that _listBox will (hopefully) have determined a reasonable
- // default geometry, add the widgets to the layout.
+ // default tqgeometry, add the widgets to the tqlayout.
- layout->addWidget( _listBox, 0 );
- layout->addWidget( _props , 1 );
- layout->activate();
+ tqlayout->addWidget( _listBox, 0 );
+ tqlayout->addWidget( _props , 1 );
+ tqlayout->activate();
}
@@ -370,7 +370,7 @@ KCleanupPage::setup()
// (Re-) Initialize list box.
- // _listBox->resize( _listBox->sizeHint() );
+ // _listBox->resize( _listBox->tqsizeHint() );
_listBox->setSelected( 0, true );
}
@@ -437,13 +437,13 @@ KCleanupListBox::KCleanupListBox( TQWidget *parent )
TQSize
-KCleanupListBox::sizeHint() const
+KCleanupListBox::tqsizeHint() const
{
// FIXME: Is this still needed with TQt 2.x?
if ( count() < 1 )
{
// As long as the list is empty, sizeHint() would default to
// (0,0) which is ALWAYS just a pain in the ass. We'd rather
// have an absolutely random value than this.
return TQSize( 100, 100 );
@@ -544,7 +544,7 @@ KCleanupPropertiesPage::KCleanupPropertiesPage( TQWidget * parent,
TQVBoxLayout *fieldsBox = new TQVBoxLayout( _fields );
// Grid layout for the edit fields, their labels, some
// explanatory text and the "recurse?" check box.
TQGridLayout *grid = new TQGridLayout( 7, // rows
@@ -611,7 +611,7 @@ KCleanupPropertiesPage::KCleanupPropertiesPage( TQWidget * parent,
_worksForProtocols->insertItem( i18n( "Network Transparent (ftp, smb, tar, ...)" ) );
// Grid layout for combo boxes at the bottom
grid = new TQGridLayout( 1, // rows
2, // cols
@@ -646,7 +646,7 @@ KCleanupPropertiesPage::KCleanupPropertiesPage( TQWidget * parent,
outerBox->activate();
- setMinimumSize( sizeHint() );
+ setMinimumSize( tqsizeHint() );
}
@@ -707,13 +707,13 @@ KGeneralSettingsPage::KGeneralSettingsPage( KSettingsDialog * dialog,
, _treeView( mainWin->treeView() )
{
- // Create layout and widgets.
+ // Create tqlayout and widgets.
- TQVBoxLayout * layout = new TQVBoxLayout( this, 5, // border
+ TQVBoxLayout * tqlayout = new TQVBoxLayout( this, 5, // border
dialog->spacingHint() ); // spacing
TQVGroupBox * gbox = new TQVGroupBox( i18n( "Directory Reading" ), this );
- layout->addWidget( gbox );
+ tqlayout->addWidget( gbox );
_crossFileSystems = new TQCheckBox( i18n( "Cross &File System Boundaries" ), gbox );
_enableLocalDirReader = new TQCheckBox( i18n( "Use Optimized &Local Directory Read Methods" ), gbox );
@@ -721,10 +721,10 @@ KGeneralSettingsPage::KGeneralSettingsPage( KSettingsDialog * dialog,
connect( _enableLocalDirReader, TQT_SIGNAL( stateChanged( int ) ),
this, TQT_SLOT ( checkEnabledState() ) );
- layout->addSpacing( 10 );
+ tqlayout->addSpacing( 10 );
gbox = new TQVGroupBox( i18n( "Animation" ), this );
- layout->addWidget( gbox );
+ tqlayout->addWidget( gbox );
_enableToolBarAnimation = new TQCheckBox( i18n( "P@cM@n Animation in Tool &Bar" ), gbox );
_enableTreeViewAnimation = new TQCheckBox( i18n( "P@cM@n Animation in Directory &Tree" ), gbox );
@@ -800,11 +800,11 @@ KTreemapPage::KTreemapPage( KSettingsDialog * dialog,
{
// kdDebug() << k_funcinfo << endl;
- TQVBoxLayout * layout = new TQVBoxLayout( this, 0, 0 ); // parent, border, spacing
+ TQVBoxLayout * tqlayout = new TQVBoxLayout( this, 0, 0 ); // parent, border, spacing
TQVBox * vbox = new TQVBox( this );
vbox->setSpacing( dialog->spacingHint() );
- layout->addWidget( vbox );
+ tqlayout->addWidget( vbox );
_squarify = new TQCheckBox( i18n( "S&quarify Treemap" ), vbox );
_doCushionShading = new TQCheckBox( i18n( "Use C&ushion Shading" ), vbox );
@@ -815,7 +815,7 @@ KTreemapPage::KTreemapPage( KSettingsDialog * dialog,
TQVGroupBox * gbox = new TQVGroupBox( i18n( "Cushion Parameters" ), vbox );
_cushionParams = gbox;
gbox->addSpace( 7 );
- gbox->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Expanding ) );
+ gbox->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Expanding ) );
TQLabel * label = new TQLabel( i18n( "Ambient &Light" ), gbox );
TQHBox * hbox = new TQHBox( gbox );
@@ -823,7 +823,7 @@ KTreemapPage::KTreemapPage( KSettingsDialog * dialog,
DefaultAmbientLight,Qt::Horizontal, hbox );
_ambientLightSB = new TQSpinBox( MinAmbientLight, MaxAmbientLight, 1, // min, max, step
hbox );
- _ambientLightSB->setSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Minimum ) );
+ _ambientLightSB->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Minimum ) );
label->setBuddy( _ambientLightSB );
gbox->addSpace( 7 );
@@ -833,7 +833,7 @@ KTreemapPage::KTreemapPage( KSettingsDialog * dialog,
DefaultHeightScalePercent,Qt::Horizontal, hbox );
_heightScalePercentSB = new TQSpinBox( MinHeightScalePercent, MaxHeightScalePercent, 1, // min, max, step
hbox );
- _heightScalePercentSB->setSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Minimum ) );
+ _heightScalePercentSB->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Minimum ) );
label->setBuddy( _heightScalePercentSB );
gbox->addSpace( 10 );
@@ -847,7 +847,7 @@ KTreemapPage::KTreemapPage( KSettingsDialog * dialog,
_cushionGridColorL = new TQLabel( " " + i18n( "Gr&id Color: " ), hbox );
_cushionGridColor = new KColorButton( hbox );
_cushionGridColorL->setBuddy( _cushionGridColor );
- _cushionGridColorL->setAlignment( AlignRight | AlignVCenter );
+ _cushionGridColorL->tqsetAlignment( AlignRight | AlignVCenter );
// addVStretch( vbox );
@@ -860,17 +860,17 @@ KTreemapPage::KTreemapPage( KSettingsDialog * dialog,
label = new TQLabel( i18n( "&Files: " ), _plainTileParams );
_fileFillColor = new KColorButton( _plainTileParams );
label->setBuddy( _fileFillColor );
- label->setAlignment( AlignRight | AlignVCenter );
+ label->tqsetAlignment( AlignRight | AlignVCenter );
label = new TQLabel( " " + i18n( "&Directories: " ), _plainTileParams );
_dirFillColor = new KColorButton( _plainTileParams );
label->setBuddy( _dirFillColor );
- label->setAlignment( AlignRight | AlignVCenter );
+ label->tqsetAlignment( AlignRight | AlignVCenter );
label = new TQLabel( i18n( "Gr&id: " ), _plainTileParams );
_outlineColor = new KColorButton( _plainTileParams );
label->setBuddy( _outlineColor );
- label->setAlignment( AlignRight | AlignVCenter );
+ label->tqsetAlignment( AlignRight | AlignVCenter );
// Misc
@@ -1035,7 +1035,7 @@ void
addHStretch( TQWidget * parent )
{
TQWidget * stretch = new TQWidget( parent );
- stretch->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, // hor
+ stretch->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, // hor
TQSizePolicy::Minimum, // vert
1, // hstretch
0 ) ); // vstretch
@@ -1046,7 +1046,7 @@ void
addVStretch( TQWidget * parent )
{
TQWidget * stretch = new TQWidget( parent );
- stretch->setSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, // hor
+ stretch->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, // hor
TQSizePolicy::Expanding, // vert
0, // hstretch
1 ) ); // vstretch
@@ -44,21 +44,21 @@ KSettingsDialog::KSettingsDialog( KDirStatApp *mainWin )
* into this - and I WANT my settings pages to be generic widgets. I want
* them to be self-sufficient - no monolithic mess of widget creation in my
- * code, intermixed with all kinds of layout objects.
+ * code, intermixed with all kinds of tqlayout objects.
*
* The ordinary KDialogBase::addPage() just creates a TQFrame which is too
@@ -166,14 +166,14 @@ KTreeColorsPage::KTreeColorsPage( KSettingsDialog * dialog,
, _maxButtons( KDirStatSettingsMaxColorButton )
{
- // Outer layout box
+ // Outer tqlayout box
TQHBoxLayout * outerBox = new TQHBoxLayout( this,
0, // border
@@ -166,14 +166,14 @@ KTreeColorsPage::KTreeColorsPage( KSettingsDialog * dialog,
0, // border
dialog->spacingHint() );
- // Inner layout box with a column of color buttons
+ // Inner tqlayout box with a column of color buttons
TQGridLayout *grid = new TQGridLayout( _maxButtons, // rows
_maxButtons + 1, // cols
@@ -437,13 +437,13 @@ KCleanupListBox::KCleanupListBox( TQWidget *parent )
if ( count() < 1 )
{
- // As long as the list is empty, sizeHint() would default to
+ // As long as the list is empty, tqsizeHint() would default to
// (0,0) which is ALWAYS just a pain in the ass. We'd rather
// have an absolutely random value than this.
@@ -544,7 +544,7 @@ KCleanupPropertiesPage::KCleanupPropertiesPage( TQWidget * parent,
TQVBoxLayout *fieldsBox = new TQVBoxLayout( _fields );
- // Grid layout for the edit fields, their labels, some
+ // Grid tqlayout for the edit fields, their labels, some
// explanatory text and the "recurse?" check box.
TQGridLayout *grid = new TQGridLayout( 7, // rows
@@ -611,7 +611,7 @@ KCleanupPropertiesPage::KCleanupPropertiesPage( TQWidget * parent,
_worksForProtocols->insertItem( i18n( "Network Transparent (ftp, smb, tar, ...)" ) );
- // Grid layout for combo boxes at the bottom
+ // Grid tqlayout for combo boxes at the bottom
grid = new TQGridLayout( 1, // rows
2, // cols